@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-""" Single and multi-threaded executors."""
+"""Single and multi-threaded executors."""
 import datetime
 import logging
+import math
 import os
 import tempfile
 import threading
@@ -303,10 +304,13 @@ class MultithreadedJobExecutor(JobExecutor):
                     % (request[rsc + "Min"], rsc, maxrsc[rsc])
                 )
             if request[rsc + "Max"] < maxrsc[rsc]:
-                result[rsc] = request[rsc + "Max"]
+                result[rsc] = math.ceil(request[rsc + "Max"])
             else:
                 result[rsc] = maxrsc[rsc]
 
+        result["tmpdirSize"] = math.ceil(request["tmpdirMin"])
+        result["outdirSize"] = math.ceil(request["outdirMin"])
+
         return result
 
     def _runner(self, job, runtime_context, TMPDIR_LOCK):
@@ -335,7 +339,9 @@ class MultithreadedJobExecutor(JobExecutor):
                     runtime_context.workflow_eval_lock.notifyAll()
 
     def run_job(
-        self, job: Optional[JobsType], runtime_context: RuntimeContext,
+        self,
+        job: Optional[JobsType],
+        runtime_context: RuntimeContext,
     ) -> None:
         """Execute a single Job in a seperate thread."""
         if job is not None:
@@ -364,11 +370,10 @@ class MultithreadedJobExecutor(JobExecutor):
                         return
 
                     if (
-                        (self.allocated_ram + job.builder.resources["ram"])
-                        > self.max_ram
-                        or (self.allocated_cores + job.builder.resources["cores"])
-                        > self.max_cores
-                    ):
+                        self.allocated_ram + job.builder.resources["ram"]
+                    ) > self.max_ram or (
+                        self.allocated_cores + job.builder.resources["cores"]
+                    ) > self.max_cores:
                         _logger.debug(
                             'Job "%s" cannot run yet, resources (%s) are not '
                             "available (already allocated ram is %d, allocated cores is %d, "
@@ -443,7 +448,7 @@ class MultithreadedJobExecutor(JobExecutor):
 
 
 class NoopJobExecutor(JobExecutor):
-    """ Do nothing executor, for testing purposes only. """
+    """Do nothing executor, for testing purposes only."""
 
     def run_jobs(
         self,
